diff --git a/Calorimeter/CaloExample/CaloDigEx/share/CaloDigCTB.py b/Calorimeter/CaloExample/CaloDigEx/share/CaloDigCTB.py
index d7a3ceccadf93373dd6099be3423da8fe1a4fdf4..280763a95d1dadecd7cef3a2ffa2fb9075705f84 100644
--- a/Calorimeter/CaloExample/CaloDigEx/share/CaloDigCTB.py
+++ b/Calorimeter/CaloExample/CaloDigEx/share/CaloDigCTB.py
@@ -94,12 +94,12 @@ theApp.Dlls += [ "GaudiAud" ]
 #
 # write out a summary of the time spent
 #
-from GaudiSvc.GaudiSvcConf import AuditorSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 svcMgr += AuditorSvc()
-from GaudiSvc.GaudiSvcConf import ChronoStatSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import ChronoStatSvc
 svcMgr += ChronoStatSvc()
 
-from GaudiSvc.GaudiSvcConf import MessageSvc
+from GaudiCoreSvc.GaudiCoreSvcConf import MessageSvc
 svcMgr += MessageSvc( defaultLimit = 100000000 )
 
 from AthenaPoolCnvSvc.WriteAthenaPool import AthenaPoolOutputStream
diff --git a/Calorimeter/CaloExample/CaloRecEx/share/CaloRecCTB.py b/Calorimeter/CaloExample/CaloRecEx/share/CaloRecCTB.py
index 6f4431ebe816e457ec1b6d0741d74529194becfe..c9b3718e4e288dca6cf44de1b39679e98411ddd8 100644
--- a/Calorimeter/CaloExample/CaloRecEx/share/CaloRecCTB.py
+++ b/Calorimeter/CaloExample/CaloRecEx/share/CaloRecCTB.py
@@ -121,12 +121,12 @@ theApp.Dlls += [ "GaudiAud" ]
 #
 # write out a summary of the time spent
 #
-from GaudiSvc.GaudiSvcConf import AuditorSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 svcMgr += AuditorSvc()
-from GaudiSvc.GaudiSvcConf import ChronoStatSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import ChronoStatSvc
 svcMgr += ChronoStatSvc()
 
-from GaudiSvc.GaudiSvcConf import MessageSvc
+from GaudiCoreSvc.GaudiCoreSvcConf import MessageSvc
 svcMgr += MessageSvc( defaultLimit = 100000000 )
 
 from AthenaPoolCnvSvc.WriteAthenaPool import AthenaPoolOutputStream
diff --git a/Control/AthenaCommon/python/AppMgr.py b/Control/AthenaCommon/python/AppMgr.py
index 6ef4fd5ede171fa1775b75e62e98c668b1d5d12a..a2afbebfb229e315e2bbdaa283a6dfef846de0a2 100755
--- a/Control/AthenaCommon/python/AppMgr.py
+++ b/Control/AthenaCommon/python/AppMgr.py
@@ -12,8 +12,8 @@ import six
 from AthenaCommon import ExitCodes
 
 from AthenaCommon import AlgSequence, Configurable, Logging
-import GaudiSvc.GaudiSvcConf as GaudiSvcConf
-
+import GaudiCoreSvc.GaudiCoreSvcConf as GaudiCoreSvcConf
+import GaudiCommonSvc.GaudiCommonSvcConf as GaudiCommonSvcConf
 
 ### data ---------------------------------------------------------------------
 __version__ = '3.2.0'
@@ -93,11 +93,11 @@ def iadd( self, tool ):
          raise TypeError( '"%s" is not an AlgTool' %
                           (hasattr(t,'name') and t.name() or "This configurable" ) )
 
-   super( GaudiSvcConf.ToolSvc, self ).__iadd__( tool )
+   super( GaudiCoreSvcConf.ToolSvc, self ).__iadd__( tool )
 
    return self
 
-GaudiSvcConf.ToolSvc.__iadd__ = iadd
+GaudiCoreSvcConf.ToolSvc.__iadd__ = iadd
 del iadd
 
 ### associator for services --------------------------------------------------
@@ -165,7 +165,7 @@ class OldToNewSequenceProxy( object ):
    pass # class OldToNewSequenceProxy
 
 ### retro application manager ------------------------------------------------
-from GaudiSvc.GaudiSvcConf import ApplicationMgr as AppMgr
+from GaudiCoreSvc.GaudiCoreSvcConf import ApplicationMgr as AppMgr
 class AthAppMgr( AppMgr ):
    class State:
       """Python equivalent of IService::State enum (kind of silly to load a whole
@@ -364,7 +364,7 @@ class AthAppMgr( AppMgr ):
             self.OutputLevel = outputLevel
          svcMgr = self.serviceMgr()
          if not hasattr( svcMgr, 'MessageSvc' ):
-            svcMgr += GaudiSvcConf.MessageSvc()
+            svcMgr += GaudiCoreSvcConf.MessageSvc()
          svcMgr.MessageSvc.OutputLevel = outputLevel
 
  # explicit user calls
@@ -395,7 +395,7 @@ class AthAppMgr( AppMgr ):
  # override toolSvc to handle the transitional one
    def toolSvc( self, name='ToolSvc' ):
       if '_toolsvc' not in self.__dict__:
-         self.__dict__[ '_toolsvc' ] = GaudiSvcConf.ToolSvc( name )
+         self.__dict__[ '_toolsvc' ] = GaudiCoreSvcConf.ToolSvc( name )
       return self._toolsvc
    toolsvc = toolSvc
 
@@ -932,12 +932,12 @@ def auditor( self, auditor ):
    self.__iadd__( auditor )
    return auditor
 
-GaudiSvcConf.AuditorSvc.auditor = auditor
+GaudiCommonSvcConf.AuditorSvc.auditor = auditor
 del auditor
 
 # convenience customization to deal with "Auditors" property
 def iadd( self, config ):
-   super( GaudiSvcConf.AuditorSvc, self ).__iadd__( config )
+   super( GaudiCommonSvcConf.AuditorSvc, self ).__iadd__( config )
 
    if isinstance( config, Configurable.ConfigurableAuditor ):
       if not config.getName()     in self.Auditors and \
@@ -946,7 +946,7 @@ def iadd( self, config ):
 
    return self
 
-GaudiSvcConf.AuditorSvc.__iadd__ =iadd
+GaudiCommonSvcConf.AuditorSvc.__iadd__ =iadd
 del iadd
 
 
@@ -967,14 +967,14 @@ def _delattr( self, attr ):
    except AttributeError:
       pass
 
-   super( GaudiSvcConf.AuditorSvc, self ).__delattr__( attr )
+   super( GaudiCommonSvcConf.AuditorSvc, self ).__delattr__( attr )
 
-GaudiSvcConf.AuditorSvc.__delattr__ = _delattr
+GaudiCommonSvcConf.AuditorSvc.__delattr__ = _delattr
 del _delattr
 
 
 # AuditorSvc globals
-ServiceMgr += GaudiSvcConf.AuditorSvc()
+ServiceMgr += GaudiCommonSvcConf.AuditorSvc()
 theAuditorSvc = ServiceMgr.AuditorSvc
 
 def AuditorSvc():             # backwards compatibility
diff --git a/Control/AthenaExamples/AthExHelloWorld/share/HelloWorld_ATN.py b/Control/AthenaExamples/AthExHelloWorld/share/HelloWorld_ATN.py
deleted file mode 100755
index e98490de74a4eb7e77292618d9fbd0b6686603ab..0000000000000000000000000000000000000000
--- a/Control/AthenaExamples/AthExHelloWorld/share/HelloWorld_ATN.py
+++ /dev/null
@@ -1,125 +0,0 @@
-###############################################################
-#
-# Job options file
-#
-#==============================================================
-
-#--------------------------------------------------------------
-# ATLAS default Application Configuration options
-#--------------------------------------------------------------
-
-# Use McEventSelector so we can run with AthenaMP
-import AthenaCommon.AtlasUnixGeneratorJob
-
-#--------------------------------------------------------------
-# Private Application Configuration options
-#--------------------------------------------------------------
-
-# Full job is a list of algorithms
-from AthenaCommon.AlgSequence import AlgSequence
-job = AlgSequence()
-
-# Add top algorithms to be run
-from AthExHelloWorld.AthExHelloWorldConf import HelloAlg
-job += HelloAlg( "HelloWorld" )   # 1 alg, named "HelloWorld"
-
-#--------------------------------------------------------------
-# Set output level threshold (DEBUG, INFO, WARNING, ERROR, FATAL)
-#--------------------------------------------------------------
-
-# Output level for HelloAlg only (note name: instance, not type)
-job.HelloWorld.OutputLevel = INFO
-
-# You can set the global output level on the message svc (not
-# recommended) or by using the -l athena CLI parameter
-
-#--------------------------------------------------------------
-# Event related parameters
-#--------------------------------------------------------------
-
-# Number of events to be processed (default is until the end of
-# input, or -1, however, since we have no input, a limit needs
-# to be set explicitly, here, choose 10)
-theApp.EvtMax = 10
-
-#--------------------------------------------------------------
-# Algorithms Private Options (all optional)
-#--------------------------------------------------------------
-
-# For convenience, get a reference to the HelloAlg Algorithm
-# named "HelloWorld" in the job
-HelloWorld = job.HelloWorld
-
-# Set an int property
-HelloWorld.MyInt = 42
-
-# Set a boolean property (False, True, 0, 1)
-HelloWorld.MyBool = True
-
-# Set a double property
-HelloWorld.MyDouble = 3.14159
-
-# Set a vector of strings property ...
-HelloWorld.MyStringVec = [ "Welcome", "to", "Athena", "Framework", "Tutorial" ]
-
-# ... and add one more:
-HelloWorld.MyStringVec += [ "!" ]
-
-# Set a map of strings to strings property ...
-HelloWorld.MyDict = { 'Bonjour'      : 'Guten Tag',
-                      'Good Morning' : 'Bonjour' , 'one' : 'uno' }
-
-# ... and add one more:
-HelloWorld.MyDict[ "Goeiedag" ] = "Ni Hao"
-
-# Set a table (a vector of pairs of doubles) ...
-HelloWorld.MyTable = [ ( 1 , 1 ) , ( 2 , 4 ) , ( 3 , 9 ) ]
-
-# ... and one more:
-HelloWorld.MyTable += [ ( 4, 16 ) ]
-
-# Set a matrix (a vector of vectors) ...
-HelloWorld.MyMatrix = [ [ 1, 2, 3 ],
-                        [ 4, 5, 6 ] ]
-
-# ... and some more:
-HelloWorld.MyMatrix += [ [ 7, 8, 9 ] ]
-
-#--------------------------------------------------------------
-# Algorithms Tool Usage Private Options (advanced and optional)
-#--------------------------------------------------------------
-
-# Import configurable for using our HelloTool
-from AthExHelloWorld.AthExHelloWorldConf import HelloTool
-
-# Setup a public tool so that it can be used (again, note name)
-ToolSvc += HelloTool( "PublicHello" )
-ToolSvc.PublicHello.MyMessage = "A Public Message!"
-
-# Tell "HelloWorld" to use this tool ("MyPublicHelloTool" is a
-# ToolHandle property of HelloAlg)
-HelloWorld.MyPublicHelloTool = ToolSvc.PublicHello
-
-# Hand "HelloWorld" a private HelloTool ("MyPrivateHelloTool" is
-# a ToolHandler property of HelloAlg)
-HelloWorld.MyPrivateHelloTool = HelloTool( "HelloTool" )
-HelloWorld.MyPrivateHelloTool.MyMessage = "A Private Message!"
-
-
-#--------------------------------------------------------------
-# Test functioning of HistorySvc
-#--------------------------------------------------------------
-
-from GaudiSvc.GaudiSvcConf import HistorySvc
-svcMgr += HistorySvc()
-svcMgr.HistorySvc.OutputFile = 'hist.xml'
-svcMgr.HistorySvc.Dump       = False
-svcMgr.HistorySvc.Activate   = True
-theApp.ActivateHistory = True
-
-#==============================================================
-#
-# End of job options file
-#
-###############################################################
-
diff --git a/Control/AthenaServices/share/SimplePOSIXTimeKeeperSvc_test.py b/Control/AthenaServices/share/SimplePOSIXTimeKeeperSvc_test.py
index 3a46f907187b28d813d9d8cb2ac7c5ca53c46ebc..40b0384d136d54797956e999935136f5e5f3b4ea 100644
--- a/Control/AthenaServices/share/SimplePOSIXTimeKeeperSvc_test.py
+++ b/Control/AthenaServices/share/SimplePOSIXTimeKeeperSvc_test.py
@@ -1,12 +1,11 @@
 ## @file SimplePOSIXTimeKeeperSvc_test.py
 # @brief  job opts for SimplePOSIXTimeKeeperSvc ATN test
 #
-# $Id: SimplePOSIXTimeKeeperSvc_test.py,v 1.4 2007-11-07 18:54:46 calaf Exp $
 
 from AthenaPython.PyAthena import Alg
 class WasteTimeAlg(Alg):
     def execute(self):
-        printfunc ("waste some time")
+        print ("waste some time")
         for i in range(200000) :
             foo = i*i/(i+1)/(i+2)
         return 1
@@ -17,7 +16,6 @@ include( "AthenaServices/SimplePOSIXTimeKeeperOptions.py" )
 
 
 from AthenaCommon.AlgSequence import AlgSequence
-from AthenaCommon.Configurable import ConfigurablePyAlgorithm
 top = AlgSequence()
 top += waste 
 
@@ -29,6 +27,3 @@ ServiceMgr.SimplePOSIXTimeKeeperSvc.OutputLevel = 1
 ServiceMgr.SimplePOSIXTimeKeeperSvc.AllocTime = 6
 
 ServiceMgr += AthenaEventLoopMgr(TimeKeeper="SimplePOSIXTimeKeeperSvc")
-
-#from GaudiSvc.GaudiSvcConf import MessageSvc
-#ServiceMgr.MessageSvc.OutputLevel = 2
diff --git a/Control/DataModelTest/DataModelRunTests/share/commonTrailer.py b/Control/DataModelTest/DataModelRunTests/share/commonTrailer.py
index 559610de91bacd65c8f4941f2f6b1579b94e197c..7e1893035fb8f0b192a3f51b45d3569f80210728 100644
--- a/Control/DataModelTest/DataModelRunTests/share/commonTrailer.py
+++ b/Control/DataModelTest/DataModelRunTests/share/commonTrailer.py
@@ -1,4 +1,4 @@
-# Copyright (C) 2002-2018 CERN for the benefit of the ATLAS collaboration.
+# Copyright (C) 2002-2020 CERN for the benefit of the ATLAS collaboration.
 
 #--------------------------------------------------------------
 # Set output level threshold (2=DEBUG, 3=INFO, 4=WARNING, 5=ERROR, 6=FATAL )
@@ -8,8 +8,8 @@ svcMgr.MessageSvc.debugLimit  = 100000
 svcMgr.ClassIDSvc.OutputLevel = 3
 
 # No stats printout
-from GaudiSvc import GaudiSvcConf
-ChronoStatSvc = GaudiSvcConf.ChronoStatSvc()
+from GaudiCommonSvc import GaudiCommonSvcConf
+ChronoStatSvc = GaudiCommonSvcConf.ChronoStatSvc()
 ChronoStatSvc.ChronoPrintOutTable = FALSE
 ChronoStatSvc.PrintUserTime       = FALSE
 ChronoStatSvc.StatPrintOutTable   = FALSE
diff --git a/Control/PerformanceMonitoring/PerfMonComps/python/JobOptCfg.py b/Control/PerformanceMonitoring/PerfMonComps/python/JobOptCfg.py
index 3ca316a2f9341c659eab6ca8466e109f4cef8b9c..639ead38e6495143ce8af05700b4d71258c157e4 100644
--- a/Control/PerformanceMonitoring/PerfMonComps/python/JobOptCfg.py
+++ b/Control/PerformanceMonitoring/PerfMonComps/python/JobOptCfg.py
@@ -80,12 +80,12 @@ class PerfMonSvc( _PerfMonSvc ):
         
         ## configure the auditor service if not done already...
         if not hasattr(svcMgr, 'AuditorSvc'):
-            from GaudiSvc.GaudiSvcConf import AuditorSvc
+            from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
             svcMgr += AuditorSvc()
         
         ## configure the chronostat service
         if not hasattr(svcMgr, 'ChronoStatSvc'):
-            from GaudiSvc.GaudiSvcConf import ChronoStatSvc
+            from GaudiCommonSvc.GaudiCommonSvcConf import ChronoStatSvc
             svcMgr += ChronoStatSvc( OutputLevel = Lvl.WARNING,
                                      ChronoPrintOutTable = False )
 
diff --git a/Control/PerformanceMonitoring/PerfMonComps/python/MTJobOptCfg.py b/Control/PerformanceMonitoring/PerfMonComps/python/MTJobOptCfg.py
index 35b25d9ba707b4f42c2c35fdcc6e9eacead1e47e..a366480824bf6c0be85767e778913f24be9a6de6 100644
--- a/Control/PerformanceMonitoring/PerfMonComps/python/MTJobOptCfg.py
+++ b/Control/PerformanceMonitoring/PerfMonComps/python/MTJobOptCfg.py
@@ -53,7 +53,7 @@ class PerfMonMTSvc ( _PerfMonMTSvc  ):
 
         ## Make sure the auditor service is there
         if not hasattr(svcMgr, 'AuditorSvc'):
-            from GaudiSvc.GaudiSvcConf import AuditorSvc
+            from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
             svcMgr += AuditorSvc()
 
         ## Turn on component-level monitoring if asked by the user
diff --git a/Control/PerformanceMonitoring/PerfMonTests/share/test_perfMonSvc_evtgen.py b/Control/PerformanceMonitoring/PerfMonTests/share/test_perfMonSvc_evtgen.py
index 8622bdf1c62654b283bc0343256e1e956f328a2f..e40b031ec3eb9e936c31ec11142178d26bcc9cfa 100755
--- a/Control/PerformanceMonitoring/PerfMonTests/share/test_perfMonSvc_evtgen.py
+++ b/Control/PerformanceMonitoring/PerfMonTests/share/test_perfMonSvc_evtgen.py
@@ -93,7 +93,7 @@ if not 'OUTPUT' in dir():
   pass
 outStream.OutputFile = OUTPUT
 
-from GaudiSvc.GaudiSvcConf import MessageSvc
+from GaudiCoreSvc.GaudiCoreSvcConf import MessageSvc
 svcMgr += MessageSvc( defaultLimit = 4000000 )
 svcMgr.MessageSvc.OutputLevel  = WARNING
 
diff --git a/Control/PerformanceMonitoring/PerfMonTests/share/test_perfMonSvc_inDetReadBS.py b/Control/PerformanceMonitoring/PerfMonTests/share/test_perfMonSvc_inDetReadBS.py
index ac44e5568a8d89f9da5b119aa69569d107d22acf..05e8adfd09c800ff384be7eb8ad98bee2b1ba589 100755
--- a/Control/PerformanceMonitoring/PerfMonTests/share/test_perfMonSvc_inDetReadBS.py
+++ b/Control/PerformanceMonitoring/PerfMonTests/share/test_perfMonSvc_inDetReadBS.py
@@ -129,7 +129,7 @@ if not doReadBS:
   #ServiceMgr.EventSelector.InputCollections += ["castor:/castor/cern.ch/grid/atlas/datafiles/egamma/DC3.007040.singlepart_gamma_Et20/digit/120031/ideal0_mc12.007040.singlepart_gamma_Et20.digit.RDO.v12003108_tid005022._00002.pool.root"]
 ###############################################################
 
-from GaudiSvc.GaudiSvcConf import MessageSvc
+from GaudiCoreSvc.GaudiCoreSvcConf import MessageSvc
 svcMgr += MessageSvc( defaultLimit = 4000000 )
 svcMgr.MessageSvc.OutputLevel  = ERROR
 
diff --git a/Control/PerformanceMonitoring/PerfMonTests/share/test_perfMonSvc_inDetWriteBS.py b/Control/PerformanceMonitoring/PerfMonTests/share/test_perfMonSvc_inDetWriteBS.py
index 24ca2802df569bddaac5ee0a3fbe1a9269cec4cc..e3903601a2806837543362c974d3dcbbd63e99ba 100755
--- a/Control/PerformanceMonitoring/PerfMonTests/share/test_perfMonSvc_inDetWriteBS.py
+++ b/Control/PerformanceMonitoring/PerfMonTests/share/test_perfMonSvc_inDetWriteBS.py
@@ -30,7 +30,7 @@ svcMgr += PerfMonSvc(
 include( "InDetRecExample/WriteInDetBS_jobOptions.py")
 ###############################################################
 
-from GaudiSvc.GaudiSvcConf import MessageSvc
+from GaudiCoreSvc.GaudiCoreSvcConf import MessageSvc
 svcMgr += MessageSvc( defaultLimit = 4000000 )
 svcMgr.MessageSvc.OutputLevel  = ERROR
 
diff --git a/Control/PerformanceMonitoring/PerfMonTests/share/test_perfMonSvc_truthjets.py b/Control/PerformanceMonitoring/PerfMonTests/share/test_perfMonSvc_truthjets.py
index a8d92c0951019f75cae4d852a93518d56c1d8156..f7f5d66a90c71c2879541eaab77643d8ccb664a2 100755
--- a/Control/PerformanceMonitoring/PerfMonTests/share/test_perfMonSvc_truthjets.py
+++ b/Control/PerformanceMonitoring/PerfMonTests/share/test_perfMonSvc_truthjets.py
@@ -99,7 +99,7 @@ if not 'OUTPUT' in dir():
   pass
 outStream.OutputFile = OUTPUT
 
-from GaudiSvc.GaudiSvcConf import MessageSvc
+from GaudiCoreSvc.GaudiCoreSvcConf import MessageSvc
 svcMgr += MessageSvc( defaultLimit = 4000000 )
 svcMgr.MessageSvc.OutputLevel  = ERROR
 
diff --git a/Event/EventInfoMgt/python/EventInfoMgtInit.py b/Event/EventInfoMgt/python/EventInfoMgtInit.py
index e144b15ba4a0593e13db0469d17e9608c30b17f0..6b9e14bbadd08cc4e088d64eb9df836b4419c87c 100755
--- a/Event/EventInfoMgt/python/EventInfoMgtInit.py
+++ b/Event/EventInfoMgt/python/EventInfoMgtInit.py
@@ -1,9 +1,8 @@
-# Copyright (C) 2002-2019 CERN for the benefit of the ATLAS collaboration
+# Copyright (C) 2002-2020 CERN for the benefit of the ATLAS collaboration
 
 ## @file EventInfoMgtInit.py
 ## @brief Configurable for TagInfoMgr service initialization
 ## @author RD Schaffer <R.D.Schaffer@cern.ch>
-## $Id: EventInfoMgtInit.py,v 1.4 2008-08-25 10:17:35 schaffer Exp $
 ###############################################################
 #
 # The jobOptions for TagInfoMgr
@@ -78,7 +77,7 @@ def _loadBasicEventInfoMgt():
     svcMgr.TagInfoMgr.ExtraTagValuePairs = {"AtlasRelease" : release }
 
     # Add TagInfoMgr as cnv svc
-    from GaudiSvc.GaudiSvcConf import EvtPersistencySvc
+    from GaudiCommonSvc.GaudiCommonSvcConf import EvtPersistencySvc
     if not hasattr (svcMgr, 'EventPersistencySvc'):
         svcMgr += EvtPersistencySvc( "EventPersistencySvc" )
     svcMgr.EventPersistencySvc.CnvServices += [ "TagInfoMgr" ]
diff --git a/InnerDetector/InDetCalibAlgs/PixelCalibAlgs/Application/createDeadModuleList.C b/InnerDetector/InDetCalibAlgs/PixelCalibAlgs/Application/createDeadModuleList.C
index 60cbc45bd3249377d90ed5c30aa3a7bd6aec39da..ce410c3c2955ffe468267b0b275380caa9069b2b 100644
--- a/InnerDetector/InDetCalibAlgs/PixelCalibAlgs/Application/createDeadModuleList.C
+++ b/InnerDetector/InDetCalibAlgs/PixelCalibAlgs/Application/createDeadModuleList.C
@@ -478,7 +478,7 @@ int main (int argc, char* argv[]){
   pyFile[LB] << "" << std::endl;
   pyFile[LB] << "### configure the event selector" << std::endl;
   pyFile[LB] << "" << std::endl;
-  pyFile[LB] << "from GaudiSvc.GaudiSvcConf import EventSelector" << std::endl;
+  pyFile[LB] << "from GaudiCoreSvc.GaudiCoreSvcConf import EventSelector" << std::endl;
   pyFile[LB] << "" << std::endl;
   pyFile[LB] << "ServiceMgr += EventSelector()" << std::endl;
   pyFile[LB] << "" << std::endl;
diff --git a/InnerDetector/InDetCalibAlgs/PixelCalibAlgs/share/MaskModulesFEforRun.sh b/InnerDetector/InDetCalibAlgs/PixelCalibAlgs/share/MaskModulesFEforRun.sh
index f2099ec090780584036253591767616123354eb9..aabbc26a6c9b8f27e6d268ba39324b8d2de09518 100755
--- a/InnerDetector/InDetCalibAlgs/PixelCalibAlgs/share/MaskModulesFEforRun.sh
+++ b/InnerDetector/InDetCalibAlgs/PixelCalibAlgs/share/MaskModulesFEforRun.sh
@@ -114,7 +114,7 @@ regSvc.OverrideTypes = [ "String4k" ]
 
 ### configure the event selector
 
-from GaudiSvc.GaudiSvcConf import EventSelector
+from GaudiCoreSvc.GaudiCoreSvcConf import EventSelector
 
 ServiceMgr += EventSelector()
 
diff --git a/InnerDetector/InDetCalibAlgs/PixelCalibAlgs/share/PixMapOverlayWriter.py b/InnerDetector/InDetCalibAlgs/PixelCalibAlgs/share/PixMapOverlayWriter.py
index 7fdd0105109e40f91a664607c204603842b5e898..ef07b758bca287702700a37104958f3ac59ff9f0 100755
--- a/InnerDetector/InDetCalibAlgs/PixelCalibAlgs/share/PixMapOverlayWriter.py
+++ b/InnerDetector/InDetCalibAlgs/PixelCalibAlgs/share/PixMapOverlayWriter.py
@@ -139,7 +139,7 @@ regSvc.OverrideTypes = [ "String4k" ]
 
 ### configure the event selector
 
-from GaudiSvc.GaudiSvcConf import EventSelector
+from GaudiCoreSvc.GaudiCoreSvcConf import EventSelector
 
 ServiceMgr += EventSelector()
 
diff --git a/InnerDetector/InDetCalibAlgs/PixelCalibAlgs/share/PixMapOverlay_IBL.py b/InnerDetector/InDetCalibAlgs/PixelCalibAlgs/share/PixMapOverlay_IBL.py
index 8d0f3eca1a59c30c3d525688e60aa4e89d2824d6..d3d89c064ef51de79f9752c8a1b256fefffe90ce 100644
--- a/InnerDetector/InDetCalibAlgs/PixelCalibAlgs/share/PixMapOverlay_IBL.py
+++ b/InnerDetector/InDetCalibAlgs/PixelCalibAlgs/share/PixMapOverlay_IBL.py
@@ -73,7 +73,7 @@ regSvc.OverrideTypes = [ "String4k" ]
 
 ### configure the event selector
 
-from GaudiSvc.GaudiSvcConf import EventSelector
+from GaudiCoreSvc.GaudiCoreSvcConf import EventSelector
 
 ServiceMgr += EventSelector()
 
diff --git a/InnerDetector/InDetCalibAlgs/PixelCalibAlgs/share/PixMapOverlay_Run2_CommandLineArguments.py b/InnerDetector/InDetCalibAlgs/PixelCalibAlgs/share/PixMapOverlay_Run2_CommandLineArguments.py
index 465817bc5fb3ee23ed03ca89d2367f448f9da082..fb5bea40bd787b85b620154f496ea179913ca359 100644
--- a/InnerDetector/InDetCalibAlgs/PixelCalibAlgs/share/PixMapOverlay_Run2_CommandLineArguments.py
+++ b/InnerDetector/InDetCalibAlgs/PixelCalibAlgs/share/PixMapOverlay_Run2_CommandLineArguments.py
@@ -145,7 +145,7 @@ regSvc.OverrideTypes = [ "String4k" ]
 
 
 ### configure the event selector
-from GaudiSvc.GaudiSvcConf import EventSelector
+from GaudiCoreSvc.GaudiCoreSvcConf import EventSelector
 
 ServiceMgr += EventSelector()
 
diff --git a/InnerDetector/InDetCalibAlgs/SCT_CalibAlgs/share/SCTCalib_topOptions.py b/InnerDetector/InDetCalibAlgs/SCT_CalibAlgs/share/SCTCalib_topOptions.py
index 5878f45764eab5431bac8164beaabdd4c24ecf6c..e99da1c20e8e4bb0ac5585ef88e1e0679f1f7a21 100755
--- a/InnerDetector/InDetCalibAlgs/SCT_CalibAlgs/share/SCTCalib_topOptions.py
+++ b/InnerDetector/InDetCalibAlgs/SCT_CalibAlgs/share/SCTCalib_topOptions.py
@@ -42,7 +42,7 @@ from AthenaCommon.AppMgr import theApp
 #--------------------------------------------------------------
 # AuditorSvc
 #--------------------------------------------------------------
-from GaudiSvc.GaudiSvcConf import AuditorSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 ServiceMgr += AuditorSvc()
 theAuditorSvc = ServiceMgr.AuditorSvc
 #--- write out a summary of the time spent
diff --git a/InnerDetector/InDetCalibAlgs/SCT_CalibAlgs/share/referenceOptions.py b/InnerDetector/InDetCalibAlgs/SCT_CalibAlgs/share/referenceOptions.py
index 5b2dcd012b669e48ecb0ebe9e5bdf02930e5e52b..0056fe12219d23db9f438afbbee8b9f4f47b86ad 100755
--- a/InnerDetector/InDetCalibAlgs/SCT_CalibAlgs/share/referenceOptions.py
+++ b/InnerDetector/InDetCalibAlgs/SCT_CalibAlgs/share/referenceOptions.py
@@ -43,7 +43,7 @@ from AthenaCommon.AppMgr import theApp
 #--------------------------------------------------------------
 # AuditorSvc
 #--------------------------------------------------------------
-from GaudiSvc.GaudiSvcConf import AuditorSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 ServiceMgr += AuditorSvc()
 theAuditorSvc = ServiceMgr.AuditorSvc
 #--- write out a summary of the time spent
diff --git a/InnerDetector/InDetCalibAlgs/SCT_CalibAlgs/share/skeleton.sct_calib.py b/InnerDetector/InDetCalibAlgs/SCT_CalibAlgs/share/skeleton.sct_calib.py
index 3d6cf3673d025e4f8997607283195b4080ce63b2..90a4d122bb953fc6d0dd2015fb357b32a341dfef 100644
--- a/InnerDetector/InDetCalibAlgs/SCT_CalibAlgs/share/skeleton.sct_calib.py
+++ b/InnerDetector/InDetCalibAlgs/SCT_CalibAlgs/share/skeleton.sct_calib.py
@@ -28,7 +28,7 @@ from AthenaCommon.AppMgr import theApp
 #--------------------------------------------------------------
 # AuditorSvc
 #--------------------------------------------------------------
-from GaudiSvc.GaudiSvcConf import AuditorSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 ServiceMgr += AuditorSvc()
 theAuditorSvc = ServiceMgr.AuditorSvc
 #--- write out a summary of the time spent
diff --git a/InnerDetector/InDetConditions/PixelConditionsTools/share/PixelDCSTestRead.py b/InnerDetector/InDetConditions/PixelConditionsTools/share/PixelDCSTestRead.py
index 17b2bf132bccabc0312b17d446462edefec2078b..e929186702572b3ad463aa0c403d5cfa4c26b961 100644
--- a/InnerDetector/InDetConditions/PixelConditionsTools/share/PixelDCSTestRead.py
+++ b/InnerDetector/InDetConditions/PixelConditionsTools/share/PixelDCSTestRead.py
@@ -3,7 +3,7 @@ import AthenaCommon.AtlasUnixStandardJob
 # use auditors
 from AthenaCommon.AppMgr import ServiceMgr
 
-from GaudiSvc.GaudiSvcConf import AuditorSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 
 ServiceMgr += AuditorSvc()
 theAuditorSvc = ServiceMgr.AuditorSvc
diff --git a/InnerDetector/InDetConditions/PixelConditionsTools/share/PixelDCSTestWrite.py b/InnerDetector/InDetConditions/PixelConditionsTools/share/PixelDCSTestWrite.py
index 1a6890648bd771888fe3582ccb665e462c8f14f6..e94bc993028dc559acd050e861980a98126a6917 100644
--- a/InnerDetector/InDetConditions/PixelConditionsTools/share/PixelDCSTestWrite.py
+++ b/InnerDetector/InDetConditions/PixelConditionsTools/share/PixelDCSTestWrite.py
@@ -5,7 +5,7 @@ from AthenaCommon.AppMgr import theApp
 from AthenaCommon.AppMgr import ServiceMgr
 
 
-## from GaudiSvc.GaudiSvcConf import AuditorSvc
+## from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 
 ## ServiceMgr += AuditorSvc()
 ## theAuditorSvc = ServiceMgr.AuditorSvc
diff --git a/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testBSError.py b/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testBSError.py
index 6dba942c005ba4a0fd071acaf6d9317626664024..c2c0a4fb4342c785cc01a8c8b8ba5d54bf12f336 100644
--- a/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testBSError.py
+++ b/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testBSError.py
@@ -18,7 +18,7 @@ if numThreads > 0:
 
 # use auditors
 from AthenaCommon.AppMgr import ServiceMgr
-from GaudiSvc.GaudiSvcConf import AuditorSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 ServiceMgr += AuditorSvc()
 theAuditorSvc = ServiceMgr.AuditorSvc
 theAuditorSvc.Auditors  += ["ChronoAuditor"]
diff --git a/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testCalibChipRead.py b/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testCalibChipRead.py
index 72db937400ba4d4d3fd19ab7a2641744f6d968c1..d60353751e1606da2398ca929c4d57a35d9806b5 100644
--- a/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testCalibChipRead.py
+++ b/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testCalibChipRead.py
@@ -30,7 +30,7 @@ PrintOutCalibDataMaps                 = False # Print out the calib defect maps
 #--------------------------------------------------------------
 from AthenaCommon.AppMgr import ServiceMgr
 
-from GaudiSvc.GaudiSvcConf import AuditorSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 from AthenaCommon.AppMgr import theApp
 
 ServiceMgr += AuditorSvc()
diff --git a/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testCalibRead.py b/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testCalibRead.py
index d25c93ffb440aa6561aac5270b32c0fbb9946db3..a15a57401e74ca4c8a9bdb85b7588124c6922280 100644
--- a/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testCalibRead.py
+++ b/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testCalibRead.py
@@ -33,7 +33,7 @@ PrintOutCalibDefectMaps               = False # Print out the calib defect maps
 #--------------------------------------------------------------
 from AthenaCommon.AppMgr import ServiceMgr
 
-from GaudiSvc.GaudiSvcConf import AuditorSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 from AthenaCommon.AppMgr import theApp
 
 ServiceMgr += AuditorSvc()
diff --git a/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testConfig.py b/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testConfig.py
index 1bc6ec7052bd6b665184774c77241a7682fe7c30..51a43800a51e766e14db34f4ba574ca6b5445ab4 100644
--- a/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testConfig.py
+++ b/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testConfig.py
@@ -21,7 +21,7 @@ if numThreads > 0:
 
 # use auditors
 from AthenaCommon.AppMgr import ServiceMgr
-from GaudiSvc.GaudiSvcConf import AuditorSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 
 ServiceMgr += AuditorSvc()
 theAuditorSvc = ServiceMgr.AuditorSvc
diff --git a/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testDCSConditions.py b/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testDCSConditions.py
index 887011c22801b5317e573e13c59f658e10638938..96b411e3397ceab2e81770642bf4d870dffc4fb5 100644
--- a/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testDCSConditions.py
+++ b/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testDCSConditions.py
@@ -29,7 +29,7 @@ if numThreads > 0:
 # use auditors
 #--------------------------------------------------------------
 from AthenaCommon.AppMgr import ServiceMgr
-from GaudiSvc.GaudiSvcConf import AuditorSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 ServiceMgr += AuditorSvc()
 theAuditorSvc = ServiceMgr.AuditorSvc
 theAuditorSvc.Auditors  += [ "ChronoAuditor"]
diff --git a/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testFlagged.py b/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testFlagged.py
index 2c8242ffd39de50277b8e3d3f1393cc3eaa5f0d9..edf7353918aae18d5dbc5485b287ee6663357aba 100644
--- a/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testFlagged.py
+++ b/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testFlagged.py
@@ -18,7 +18,7 @@ if numThreads > 0:
 
 # use auditors
 from AthenaCommon.AppMgr import ServiceMgr
-from GaudiSvc.GaudiSvcConf import AuditorSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 ServiceMgr += AuditorSvc()
 theAuditorSvc = ServiceMgr.AuditorSvc
 theAuditorSvc.Auditors  += ["ChronoAuditor"]
diff --git a/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testLinkMasking.py b/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testLinkMasking.py
index 4a2404dc5f27e54e48b13a6860c65e530edb4c48..2322b0e3721122febbe406b22c429ea7f3a029b2 100644
--- a/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testLinkMasking.py
+++ b/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testLinkMasking.py
@@ -19,7 +19,7 @@ if numThreads > 0:
 # use auditors
 from AthenaCommon.AppMgr import ServiceMgr
 
-from GaudiSvc.GaudiSvcConf import AuditorSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 
 ServiceMgr += AuditorSvc()
 theAuditorSvc = ServiceMgr.AuditorSvc
diff --git a/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testMajority.py b/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testMajority.py
index c749b4d61739bbc58ec07e74e225870ed235f9cd..ad3bdddc8f0d48a9c225f4c03ede290d75f8293a 100644
--- a/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testMajority.py
+++ b/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testMajority.py
@@ -18,7 +18,7 @@ if numThreads > 0:
 
 # use auditors
 from AthenaCommon.AppMgr import ServiceMgr
-from GaudiSvc.GaudiSvcConf import AuditorSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 ServiceMgr += AuditorSvc()
 theAuditorSvc = ServiceMgr.AuditorSvc
 theAuditorSvc.Auditors  += [ "ChronoAuditor"]
diff --git a/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testModuleVeto.py b/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testModuleVeto.py
index a39c05dc7be604ca30e616150220a5bff4648d2b..015eb1526c8c8274b30f1c6840d9500d76e705c8 100644
--- a/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testModuleVeto.py
+++ b/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testModuleVeto.py
@@ -18,7 +18,7 @@ if numThreads > 0:
 
 # use auditors
 from AthenaCommon.AppMgr import ServiceMgr
-from GaudiSvc.GaudiSvcConf import AuditorSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 ServiceMgr += AuditorSvc()
 theAuditorSvc = ServiceMgr.AuditorSvc
 theAuditorSvc.Auditors  += [ "ChronoAuditor"]
diff --git a/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testMonRead.py b/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testMonRead.py
index 65b374b210eaa149c7baa70f1d7cf6753408c57d..de6fec96bae63974214bf82a612bbc33eb8dea77 100644
--- a/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testMonRead.py
+++ b/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testMonRead.py
@@ -14,7 +14,7 @@ if numThreads > 0:
 # use auditors
 from AthenaCommon.AppMgr import ServiceMgr
 
-from GaudiSvc.GaudiSvcConf import AuditorSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 
 ServiceMgr += AuditorSvc()
 theAuditorSvc = ServiceMgr.AuditorSvc
diff --git a/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testParameters.py b/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testParameters.py
index 3db839a88a974af0cacbccfaab8b8d21ed7efee9..9cf72f8b7c335a38ddf4d101f787efac9541dcc8 100644
--- a/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testParameters.py
+++ b/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testParameters.py
@@ -29,7 +29,7 @@ if numThreads > 0:
 # use auditors
 #--------------------------------------------------------------
 from AthenaCommon.AppMgr import ServiceMgr
-from GaudiSvc.GaudiSvcConf import AuditorSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 ServiceMgr += AuditorSvc()
 theAuditorSvc = ServiceMgr.AuditorSvc
 theAuditorSvc.Auditors  += [ "ChronoAuditor"]
diff --git a/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testReadout.py b/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testReadout.py
index b317d7d79635fcdfc2f641d2c2b2dbf6885b89c8..ea48d4e7f413e4f5ea2bb68ec627dbbf479d069e 100644
--- a/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testReadout.py
+++ b/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testReadout.py
@@ -18,7 +18,7 @@ if numThreads > 0:
 
 # use auditors
 from AthenaCommon.AppMgr import ServiceMgr
-from GaudiSvc.GaudiSvcConf import AuditorSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 ServiceMgr += AuditorSvc()
 theAuditorSvc = ServiceMgr.AuditorSvc
 theAuditorSvc.Auditors  += [ "ChronoAuditor"]
diff --git a/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testRodVeto.py b/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testRodVeto.py
index ad65727fede86d7253846706f71dfe0bc032c99c..eee94045944ea3e2c9e6decad140c3be3b6bcbc6 100644
--- a/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testRodVeto.py
+++ b/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testRodVeto.py
@@ -19,7 +19,7 @@ if numThreads > 0:
 # use auditors
 from AthenaCommon.AppMgr import ServiceMgr
 
-from GaudiSvc.GaudiSvcConf import AuditorSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 
 ServiceMgr += AuditorSvc()
 theAuditorSvc = ServiceMgr.AuditorSvc
diff --git a/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testSensors.py b/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testSensors.py
index 1b4f7720c55b8054d7445aa6d4db6227f8a3c180..36b339b19feb44c60245162169cd4a2878e9473b 100644
--- a/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testSensors.py
+++ b/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testSensors.py
@@ -19,7 +19,7 @@ if numThreads > 0:
 # use auditors
 from AthenaCommon.AppMgr import ServiceMgr
 
-from GaudiSvc.GaudiSvcConf import AuditorSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 
 ServiceMgr += AuditorSvc()
 theAuditorSvc = ServiceMgr.AuditorSvc
diff --git a/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testSilicon.py b/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testSilicon.py
index 64c992f259014092c0fa507d0a4d99569dff2d58..cec5ef233c3e1f82a5ce714935cf04587be4d7e0 100644
--- a/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testSilicon.py
+++ b/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testSilicon.py
@@ -20,7 +20,7 @@ if numThreads > 0:
 
 # use auditors
 from AthenaCommon.AppMgr import ServiceMgr
-from GaudiSvc.GaudiSvcConf import AuditorSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 ServiceMgr += AuditorSvc()
 theAuditorSvc = ServiceMgr.AuditorSvc
 theAuditorSvc.Auditors  += [ "ChronoAuditor"]
diff --git a/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testStripVeto.py b/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testStripVeto.py
index 8bb8b109f94fd77b070da21f4db718a4123ea171..16c8faa67752b583c84defa8ab2270ae6287b651 100644
--- a/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testStripVeto.py
+++ b/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testStripVeto.py
@@ -18,7 +18,7 @@ if numThreads > 0:
 
 # use auditors
 from AthenaCommon.AppMgr import ServiceMgr
-from GaudiSvc.GaudiSvcConf import AuditorSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 ServiceMgr += AuditorSvc()
 theAuditorSvc = ServiceMgr.AuditorSvc
 theAuditorSvc.Auditors  += ["ChronoAuditor"]
diff --git a/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testSummary.py b/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testSummary.py
index 481a61be5eafdf0233cb8c99a93f9e936684f96d..0105c64fa9ddf391f9fa1aff5895c122fe8bbffc 100644
--- a/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testSummary.py
+++ b/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testSummary.py
@@ -18,7 +18,7 @@ if numThreads > 0:
 
 # use auditors
 from AthenaCommon.AppMgr import ServiceMgr
-from GaudiSvc.GaudiSvcConf import AuditorSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 ServiceMgr += AuditorSvc()
 theAuditorSvc = ServiceMgr.AuditorSvc
 theAuditorSvc.Auditors  += [ "ChronoAuditor"]
diff --git a/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testTdaqEnabled.py b/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testTdaqEnabled.py
index ae84c18198a0b6c6286eb9ff4078b46a3ee8e48d..5d98393656d32599bc6158f8e309498b7dc086de 100644
--- a/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testTdaqEnabled.py
+++ b/InnerDetector/InDetConditions/SCT_ConditionsAlgorithms/share/testTdaqEnabled.py
@@ -30,7 +30,7 @@ if numThreads > 0:
 #--------------------------------------------------------------
 from AthenaCommon.AppMgr import ServiceMgr
 
-from GaudiSvc.GaudiSvcConf import AuditorSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 
 ServiceMgr += AuditorSvc()
 theAuditorSvc = ServiceMgr.AuditorSvc
diff --git a/InnerDetector/InDetConditions/SiLorentzAngleTool/share/testSCTLorentzAngle.py b/InnerDetector/InDetConditions/SiLorentzAngleTool/share/testSCTLorentzAngle.py
index ef7cd2c1f2a19111964178ab248810f6df0a605e..ddc57420fe044c514691e3d8778b7a4eed9d2263 100644
--- a/InnerDetector/InDetConditions/SiLorentzAngleTool/share/testSCTLorentzAngle.py
+++ b/InnerDetector/InDetConditions/SiLorentzAngleTool/share/testSCTLorentzAngle.py
@@ -18,7 +18,7 @@ if numThreads > 0:
 
 # use auditors
 from AthenaCommon.AppMgr import ServiceMgr
-from GaudiSvc.GaudiSvcConf import AuditorSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 ServiceMgr += AuditorSvc()
 theAuditorSvc = ServiceMgr.AuditorSvc
 theAuditorSvc.Auditors  += [ "ChronoAuditor"]
diff --git a/InnerDetector/InDetConditions/SiPropertiesTool/share/testSCTProperties.py b/InnerDetector/InDetConditions/SiPropertiesTool/share/testSCTProperties.py
index 00e834606fa41fbd8a7cc2b0246d54c399df19dc..d12507a83c0c614889014347ac88e1b653c4674b 100644
--- a/InnerDetector/InDetConditions/SiPropertiesTool/share/testSCTProperties.py
+++ b/InnerDetector/InDetConditions/SiPropertiesTool/share/testSCTProperties.py
@@ -18,7 +18,7 @@ if numThreads > 0:
 
 # use auditors
 from AthenaCommon.AppMgr import ServiceMgr
-from GaudiSvc.GaudiSvcConf import AuditorSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 ServiceMgr += AuditorSvc()
 theAuditorSvc = ServiceMgr.AuditorSvc
 theAuditorSvc.Auditors  += [ "ChronoAuditor"]
diff --git a/InnerDetector/InDetDetDescr/SCT_Cabling/share/SCT_CablingWriteToFile.py b/InnerDetector/InDetDetDescr/SCT_Cabling/share/SCT_CablingWriteToFile.py
index 82889d2dec3ba42c6609beeae1137d0cc1ff5ba1..51887684cab8d81cf9ead6fa98e7ec9ec482941a 100644
--- a/InnerDetector/InDetDetDescr/SCT_Cabling/share/SCT_CablingWriteToFile.py
+++ b/InnerDetector/InDetDetDescr/SCT_Cabling/share/SCT_CablingWriteToFile.py
@@ -53,7 +53,7 @@ ServiceMgr.IOVDbSvc.OutputToFile = True
 #--------------------------------------------------------------
 # use auditors
 #--------------------------------------------------------------
-from GaudiSvc.GaudiSvcConf import AuditorSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 ServiceMgr += AuditorSvc()
 ServiceMgr.AuditorSvc.Auditors += [ "ChronoAuditor"]
 ServiceMgr.AuditorSvc.Auditors += [ "MemStatAuditor" ]
diff --git a/InnerDetector/InDetDetDescr/SCT_Cabling/share/TestSCT_Cabling.py b/InnerDetector/InDetDetDescr/SCT_Cabling/share/TestSCT_Cabling.py
index bbb3db43e3d0040800ed68a53ed6f15907325469..c48be853521acd2096c65c8a3cce2c80426c0164 100644
--- a/InnerDetector/InDetDetDescr/SCT_Cabling/share/TestSCT_Cabling.py
+++ b/InnerDetector/InDetDetDescr/SCT_Cabling/share/TestSCT_Cabling.py
@@ -23,7 +23,7 @@ if numThreads > 0:
 #--------------------------------------------------------------
 from AthenaCommon.AppMgr import ServiceMgr
 
-from GaudiSvc.GaudiSvcConf import AuditorSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 from AthenaCommon.AppMgr import theApp
 
 ServiceMgr += AuditorSvc()
diff --git a/InnerDetector/InDetDetDescr/SCT_Cabling/share/TestSCT_CablingFromCrest.py b/InnerDetector/InDetDetDescr/SCT_Cabling/share/TestSCT_CablingFromCrest.py
index d7253d8ded4740ed19c7d07ed0a79ec32c636cdf..396f6ac08b0b218db78a36890062e09c2dd8569d 100644
--- a/InnerDetector/InDetDetDescr/SCT_Cabling/share/TestSCT_CablingFromCrest.py
+++ b/InnerDetector/InDetDetDescr/SCT_Cabling/share/TestSCT_CablingFromCrest.py
@@ -45,7 +45,7 @@ ServiceMgr.IOVDbSvc.OutputLevel = DEBUG
 #--------------------------------------------------------------
 # use auditors
 #--------------------------------------------------------------
-from GaudiSvc.GaudiSvcConf import AuditorSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 ServiceMgr += AuditorSvc()
 ServiceMgr.AuditorSvc.Auditors += [ "ChronoAuditor"]
 ServiceMgr.AuditorSvc.Auditors += [ "MemStatAuditor" ]
diff --git a/InnerDetector/InDetDetDescr/SCT_Cabling/share/TestSCT_CablingSimple.py b/InnerDetector/InDetDetDescr/SCT_Cabling/share/TestSCT_CablingSimple.py
index e5b3e78ae96c8ae38f9ea94f2b9cd181bf1b8fd7..f0e9ecfa22e2a118f7ffd3fee0c28c4aa9d99e31 100644
--- a/InnerDetector/InDetDetDescr/SCT_Cabling/share/TestSCT_CablingSimple.py
+++ b/InnerDetector/InDetDetDescr/SCT_Cabling/share/TestSCT_CablingSimple.py
@@ -52,7 +52,7 @@ ServiceMgr.IOVDbSvc.OutputLevel = DEBUG
 #--------------------------------------------------------------
 # use auditors
 #--------------------------------------------------------------
-from GaudiSvc.GaudiSvcConf import AuditorSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 ServiceMgr += AuditorSvc()
 ServiceMgr.AuditorSvc.Auditors += [ "ChronoAuditor"]
 ServiceMgr.AuditorSvc.Auditors += [ "MemStatAuditor" ]
diff --git a/InnerDetector/InDetEventCnv/SCT_RawDataByteStreamCnv/share/testSCTDecode.py b/InnerDetector/InDetEventCnv/SCT_RawDataByteStreamCnv/share/testSCTDecode.py
index 03d21f9f4b36f50bebdfa80823cf21a80a0cd19a..86f8b956688300b79079e9e406453a3dd190fd00 100644
--- a/InnerDetector/InDetEventCnv/SCT_RawDataByteStreamCnv/share/testSCTDecode.py
+++ b/InnerDetector/InDetEventCnv/SCT_RawDataByteStreamCnv/share/testSCTDecode.py
@@ -37,7 +37,7 @@ if numThreads > 0:
 # use auditors
 #--------------------------------------------------------------
 from AthenaCommon.AppMgr import ServiceMgr
-from GaudiSvc.GaudiSvcConf import AuditorSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 ServiceMgr += AuditorSvc()
 theAuditorSvc = ServiceMgr.AuditorSvc
 theAuditorSvc.Auditors  += [ "ChronoAuditor"]
diff --git a/InnerDetector/InDetEventCnv/SCT_RawDataByteStreamCnv/share/testSCTEncode.py b/InnerDetector/InDetEventCnv/SCT_RawDataByteStreamCnv/share/testSCTEncode.py
index 417a9c770edb2e289092c63fc39d82436e94963b..92c530c0650655e98e2d3f765297516422ac7209 100644
--- a/InnerDetector/InDetEventCnv/SCT_RawDataByteStreamCnv/share/testSCTEncode.py
+++ b/InnerDetector/InDetEventCnv/SCT_RawDataByteStreamCnv/share/testSCTEncode.py
@@ -35,7 +35,7 @@ if numThreads > 0:
 # use auditors
 #--------------------------------------------------------------
 from AthenaCommon.AppMgr import ServiceMgr
-from GaudiSvc.GaudiSvcConf import AuditorSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 ServiceMgr += AuditorSvc()
 theAuditorSvc = ServiceMgr.AuditorSvc
 theAuditorSvc.Auditors  += [ "ChronoAuditor"]
diff --git a/InnerDetector/InDetMonitoring/SCT_Monitoring/share/SCTMonitor_topOptions.py b/InnerDetector/InDetMonitoring/SCT_Monitoring/share/SCTMonitor_topOptions.py
index 482b645bea914022095c018c8bec10699edf3ab8..bf8dbada0737f7c22d8380fcece5ff13aa9a033a 100644
--- a/InnerDetector/InDetMonitoring/SCT_Monitoring/share/SCTMonitor_topOptions.py
+++ b/InnerDetector/InDetMonitoring/SCT_Monitoring/share/SCTMonitor_topOptions.py
@@ -175,7 +175,7 @@ SCTTimeDependentMonTool = SCTTimeDependentMonTool("SCTTimeDependentMonTool")
 #SCTMonMan.AthenaMonTools += [SCTTimeDependentMonTool]
 
 ## # Auditors 
-## from GaudiSvc.GaudiSvcConf import AuditorSvc
+## from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 ## ServiceMgr.AuditorSvc.Auditors  += [ "ChronoAuditor"]
 
 ## AthenaPoolCnvSvc = Service("AthenaPoolCnvSvc")
diff --git a/InnerDetector/InDetRecAlgs/SiSPSeededTrackFinder/share/ConvertTrackToxAODTrackParticle.py b/InnerDetector/InDetRecAlgs/SiSPSeededTrackFinder/share/ConvertTrackToxAODTrackParticle.py
index e58b3e508331e2afe938bc1eaafdd0c2801ff889..fe7fc8dad4185d5b039aab821e7b8cf92b8ff8b6 100644
--- a/InnerDetector/InDetRecAlgs/SiSPSeededTrackFinder/share/ConvertTrackToxAODTrackParticle.py
+++ b/InnerDetector/InDetRecAlgs/SiSPSeededTrackFinder/share/ConvertTrackToxAODTrackParticle.py
@@ -51,7 +51,7 @@ if numThreads > 0:
 #--------------------------------------------------------------
 # use auditors
 #--------------------------------------------------------------
-from GaudiSvc.GaudiSvcConf import AuditorSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 ServiceMgr += AuditorSvc()
 theAuditorSvc = ServiceMgr.AuditorSvc
 theAuditorSvc.Auditors  += [ "ChronoAuditor"]
diff --git a/InnerDetector/InDetRecAlgs/SiSPSeededTrackFinder/share/SiSPSeededTracksStandalone.py b/InnerDetector/InDetRecAlgs/SiSPSeededTrackFinder/share/SiSPSeededTracksStandalone.py
index 1306e87e1a9a18c5df013ec7d050b35c55ec4706..a9db2d8b2b2a64b387ebfae222d688e7a63be924 100644
--- a/InnerDetector/InDetRecAlgs/SiSPSeededTrackFinder/share/SiSPSeededTracksStandalone.py
+++ b/InnerDetector/InDetRecAlgs/SiSPSeededTrackFinder/share/SiSPSeededTracksStandalone.py
@@ -72,7 +72,7 @@ if numThreads > 0:
 #--------------------------------------------------------------
 # use auditors
 #--------------------------------------------------------------
-from GaudiSvc.GaudiSvcConf import AuditorSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 ServiceMgr += AuditorSvc()
 theAuditorSvc = ServiceMgr.AuditorSvc
 theAuditorSvc.Auditors  += [ "ChronoAuditor"]
diff --git a/InnerDetector/InDetRecAlgs/SiSPSeededTrackFinder/share/SiSPSeededTracksStandaloneFromESD.py b/InnerDetector/InDetRecAlgs/SiSPSeededTrackFinder/share/SiSPSeededTracksStandaloneFromESD.py
index a09c78c4d7d1e05a2e20c1eb5cb83daa7989716e..c302596a57458dff2e682c4a16f9866231302af9 100644
--- a/InnerDetector/InDetRecAlgs/SiSPSeededTrackFinder/share/SiSPSeededTracksStandaloneFromESD.py
+++ b/InnerDetector/InDetRecAlgs/SiSPSeededTrackFinder/share/SiSPSeededTracksStandaloneFromESD.py
@@ -66,7 +66,7 @@ if numThreads > 0:
 #--------------------------------------------------------------
 # use auditors
 #--------------------------------------------------------------
-from GaudiSvc.GaudiSvcConf import AuditorSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 ServiceMgr += AuditorSvc()
 theAuditorSvc = ServiceMgr.AuditorSvc
 theAuditorSvc.Auditors  += [ "ChronoAuditor"]
diff --git a/MuonSpectrometer/MuonConditions/MuonCondGeneral/MuonCondTest/share/AllCondSummary_topOptionsMT.py b/MuonSpectrometer/MuonConditions/MuonCondGeneral/MuonCondTest/share/AllCondSummary_topOptionsMT.py
index 8d6a5498f445250c329fcf677e11995ac2e70f30..71102d7ba3565b3e05ca0d953438458333dffe9f 100644
--- a/MuonSpectrometer/MuonConditions/MuonCondGeneral/MuonCondTest/share/AllCondSummary_topOptionsMT.py
+++ b/MuonSpectrometer/MuonConditions/MuonCondGeneral/MuonCondTest/share/AllCondSummary_topOptionsMT.py
@@ -28,7 +28,7 @@ import AthenaCommon.AtlasUnixStandardJob
 # use auditors
 from AthenaCommon.AppMgr import ServiceMgr,athCondSeq
 
-from GaudiSvc.GaudiSvcConf import AuditorSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 
 ServiceMgr += AuditorSvc()
 theAuditorSvc = ServiceMgr.AuditorSvc
diff --git a/MuonSpectrometer/MuonConditions/MuonCondGeneral/MuonCondTest/share/CSCCondSummary_topOptionsMT.py b/MuonSpectrometer/MuonConditions/MuonCondGeneral/MuonCondTest/share/CSCCondSummary_topOptionsMT.py
index 32aef9e824a9a8d8995963fdd48aa6ed8c9574de..2550ee74a9647d1edf9fb2ac87fbf4152dd6d3ab 100644
--- a/MuonSpectrometer/MuonConditions/MuonCondGeneral/MuonCondTest/share/CSCCondSummary_topOptionsMT.py
+++ b/MuonSpectrometer/MuonConditions/MuonCondGeneral/MuonCondTest/share/CSCCondSummary_topOptionsMT.py
@@ -27,7 +27,7 @@ import AthenaCommon.AtlasUnixStandardJob
 # use auditors
 from AthenaCommon.AppMgr import ServiceMgr,athCondSeq
 
-from GaudiSvc.GaudiSvcConf import AuditorSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 
 ServiceMgr += AuditorSvc()
 theAuditorSvc = ServiceMgr.AuditorSvc
diff --git a/MuonSpectrometer/MuonConditions/MuonCondGeneral/MuonCondTest/share/MDTCondSummary_topOptions.py b/MuonSpectrometer/MuonConditions/MuonCondGeneral/MuonCondTest/share/MDTCondSummary_topOptions.py
index 2fde606d0f16db0b57ca8680f935d29a81bb0d2d..061569241210d1968df9b13cb04eee6769d4b658 100644
--- a/MuonSpectrometer/MuonConditions/MuonCondGeneral/MuonCondTest/share/MDTCondSummary_topOptions.py
+++ b/MuonSpectrometer/MuonConditions/MuonCondGeneral/MuonCondTest/share/MDTCondSummary_topOptions.py
@@ -7,7 +7,7 @@ import AthenaCommon.AtlasUnixStandardJob
 # use auditors
 from AthenaCommon.AppMgr import ServiceMgr
 
-from GaudiSvc.GaudiSvcConf import AuditorSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 
 ServiceMgr += AuditorSvc()
 theAuditorSvc = ServiceMgr.AuditorSvc
diff --git a/MuonSpectrometer/MuonConditions/MuonCondGeneral/MuonCondTest/share/MDTCondSummary_topOptionsMT.py b/MuonSpectrometer/MuonConditions/MuonCondGeneral/MuonCondTest/share/MDTCondSummary_topOptionsMT.py
index f8a4887a3681e6804c5f0774a8f39d765acef266..62061e37b310edf5b82c3dd34a2854d79f459490 100644
--- a/MuonSpectrometer/MuonConditions/MuonCondGeneral/MuonCondTest/share/MDTCondSummary_topOptionsMT.py
+++ b/MuonSpectrometer/MuonConditions/MuonCondGeneral/MuonCondTest/share/MDTCondSummary_topOptionsMT.py
@@ -27,7 +27,7 @@ import AthenaCommon.AtlasUnixStandardJob
 # use auditors
 from AthenaCommon.AppMgr import ServiceMgr,athCondSeq
 
-from GaudiSvc.GaudiSvcConf import AuditorSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 
 ServiceMgr += AuditorSvc()
 theAuditorSvc = ServiceMgr.AuditorSvc
diff --git a/MuonSpectrometer/MuonConditions/MuonCondGeneral/MuonCondTest/share/MuonConditionsHistoSummary.py b/MuonSpectrometer/MuonConditions/MuonCondGeneral/MuonCondTest/share/MuonConditionsHistoSummary.py
index b207221b03bf0ba809d0f8ba9bb2f0a16035e135..37c98db90f0839e10aeed44036db8a5918499dac 100644
--- a/MuonSpectrometer/MuonConditions/MuonCondGeneral/MuonCondTest/share/MuonConditionsHistoSummary.py
+++ b/MuonSpectrometer/MuonConditions/MuonCondGeneral/MuonCondTest/share/MuonConditionsHistoSummary.py
@@ -11,7 +11,7 @@ import AthenaCommon.AtlasUnixStandardJob
 # use auditors
 from AthenaCommon.AppMgr import ServiceMgr
 
-from GaudiSvc.GaudiSvcConf import AuditorSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 
 ServiceMgr += AuditorSvc()
 theAuditorSvc = ServiceMgr.AuditorSvc
diff --git a/MuonSpectrometer/MuonConditions/MuonCondGeneral/MuonCondTest/share/MuonConditionsSummary_jobOptions.py b/MuonSpectrometer/MuonConditions/MuonCondGeneral/MuonCondTest/share/MuonConditionsSummary_jobOptions.py
index 1886300a7858a0fbf489c1fba85cfe78efab9d6e..15fbcb86a609fae16e37a1f4b0cab208eee8b2b2 100644
--- a/MuonSpectrometer/MuonConditions/MuonCondGeneral/MuonCondTest/share/MuonConditionsSummary_jobOptions.py
+++ b/MuonSpectrometer/MuonConditions/MuonCondGeneral/MuonCondTest/share/MuonConditionsSummary_jobOptions.py
@@ -11,7 +11,7 @@ import AthenaCommon.AtlasUnixStandardJob
 # use auditors
 from AthenaCommon.AppMgr import ServiceMgr
 
-from GaudiSvc.GaudiSvcConf import AuditorSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 
 ServiceMgr += AuditorSvc()
 theAuditorSvc = ServiceMgr.AuditorSvc
diff --git a/MuonSpectrometer/MuonConditions/MuonCondGeneral/MuonCondTest/share/RPCCondSummary_topOptions.py b/MuonSpectrometer/MuonConditions/MuonCondGeneral/MuonCondTest/share/RPCCondSummary_topOptions.py
index d6a15bc73454f5ed368c90eae613b893a71b4693..b35fabc0b3745a6871f53fd32327f8066cd95e9e 100644
--- a/MuonSpectrometer/MuonConditions/MuonCondGeneral/MuonCondTest/share/RPCCondSummary_topOptions.py
+++ b/MuonSpectrometer/MuonConditions/MuonCondGeneral/MuonCondTest/share/RPCCondSummary_topOptions.py
@@ -7,7 +7,7 @@ import AthenaCommon.AtlasUnixStandardJob
 # use auditors
 from AthenaCommon.AppMgr import ServiceMgr
 
-from GaudiSvc.GaudiSvcConf import AuditorSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 
 ServiceMgr += AuditorSvc()
 theAuditorSvc = ServiceMgr.AuditorSvc
diff --git a/MuonSpectrometer/MuonConditions/MuonCondGeneral/MuonCondTest/share/Summary_jobOptions.py b/MuonSpectrometer/MuonConditions/MuonCondGeneral/MuonCondTest/share/Summary_jobOptions.py
index af95450f53bfd0f840db139416b2a667b1ed418c..52a90c2b103be3b917d98ce4f664fb71bde17e73 100644
--- a/MuonSpectrometer/MuonConditions/MuonCondGeneral/MuonCondTest/share/Summary_jobOptions.py
+++ b/MuonSpectrometer/MuonConditions/MuonCondGeneral/MuonCondTest/share/Summary_jobOptions.py
@@ -7,7 +7,7 @@ import AthenaCommon.AtlasUnixStandardJob
 # use auditors
 from AthenaCommon.AppMgr import ServiceMgr
 
-from GaudiSvc.GaudiSvcConf import AuditorSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 
 ServiceMgr += AuditorSvc()
 theAuditorSvc = ServiceMgr.AuditorSvc
diff --git a/MuonSpectrometer/MuonConditions/MuonCondGeneral/MuonCondTest/share/testSummary.py b/MuonSpectrometer/MuonConditions/MuonCondGeneral/MuonCondTest/share/testSummary.py
index 9b61c94f8fe1207a492ded624114cbe57c86f554..2fe07ee1dbe02d8c7ddf1f19832a890e1efed8e0 100644
--- a/MuonSpectrometer/MuonConditions/MuonCondGeneral/MuonCondTest/share/testSummary.py
+++ b/MuonSpectrometer/MuonConditions/MuonCondGeneral/MuonCondTest/share/testSummary.py
@@ -3,7 +3,7 @@ import AthenaCommon.AtlasUnixStandardJob
 # use auditors
 from AthenaCommon.AppMgr import ServiceMgr
 
-from GaudiSvc.GaudiSvcConf import AuditorSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 
 ServiceMgr += AuditorSvc()
 theAuditorSvc = ServiceMgr.AuditorSvc
diff --git a/PhysicsAnalysis/AnalysisCommon/AnalysisExamples/share/TrigAnalysisExample_jobOptions.py b/PhysicsAnalysis/AnalysisCommon/AnalysisExamples/share/TrigAnalysisExample_jobOptions.py
index 670d67619b8fe838b359fe01373fc952d1e21788..78e7101d233ea5d8e262d97d71263884961d3ca4 100644
--- a/PhysicsAnalysis/AnalysisCommon/AnalysisExamples/share/TrigAnalysisExample_jobOptions.py
+++ b/PhysicsAnalysis/AnalysisCommon/AnalysisExamples/share/TrigAnalysisExample_jobOptions.py
@@ -53,7 +53,7 @@ ServiceMgr.MessageSvc.OutputLevel = WARNING
 # Number of Events to process
 theApp.EvtMax = 10
 
-from GaudiSvc.GaudiSvcConf import AuditorSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 ServiceMgr.AuditorSvc.Auditors  += [ "ChronoAuditor"]
 
 AthenaPoolCnvSvc = Service("AthenaPoolCnvSvc")
diff --git a/PhysicsAnalysis/AnalysisCommon/UserAnalysis/share/AnalysisSkeleton_topOptions.py b/PhysicsAnalysis/AnalysisCommon/UserAnalysis/share/AnalysisSkeleton_topOptions.py
index fc732f3c2a3523cad71bbad309296921ccbeafd9..0a96b4462f08a7e562120ff47a8b4362fe3be5f1 100755
--- a/PhysicsAnalysis/AnalysisCommon/UserAnalysis/share/AnalysisSkeleton_topOptions.py
+++ b/PhysicsAnalysis/AnalysisCommon/UserAnalysis/share/AnalysisSkeleton_topOptions.py
@@ -203,7 +203,7 @@ theApp.EvtMax = -1
 ###################### For interactive analysis
 #include ("PyAnalysisCore/InitPyAnalysisCore.py")
 
-from GaudiSvc.GaudiSvcConf import AuditorSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 ServiceMgr.AuditorSvc.Auditors  += [ "ChronoAuditor"]
 
 AthenaPoolCnvSvc = Service("AthenaPoolCnvSvc")
diff --git a/PhysicsAnalysis/AnalysisCommon/UserAnalysis/share/AnalysisSkeleton_topOptions_AutoConfig.py b/PhysicsAnalysis/AnalysisCommon/UserAnalysis/share/AnalysisSkeleton_topOptions_AutoConfig.py
index ad58400950fd178a024e6c3224dd0226ab5412a9..6658798ccf1e7877afac08d56e83fb4549cf91f4 100644
--- a/PhysicsAnalysis/AnalysisCommon/UserAnalysis/share/AnalysisSkeleton_topOptions_AutoConfig.py
+++ b/PhysicsAnalysis/AnalysisCommon/UserAnalysis/share/AnalysisSkeleton_topOptions_AutoConfig.py
@@ -223,7 +223,7 @@ theApp.EvtMax = -1
 ###################### For interactive analysis
 #include ("PyAnalysisCore/InitPyAnalysisCore.py")
 
-from GaudiSvc.GaudiSvcConf import AuditorSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 ServiceMgr.AuditorSvc.Auditors  += [ "ChronoAuditor"]
 
 AthenaPoolCnvSvc = Service("AthenaPoolCnvSvc")
diff --git a/PhysicsAnalysis/AnalysisCommon/UserAnalysis/share/AnalysisSkeleton_topOptions_NEW.py b/PhysicsAnalysis/AnalysisCommon/UserAnalysis/share/AnalysisSkeleton_topOptions_NEW.py
index a41f9edfdda554554222e35024dd4279d4c04fc6..b7a323d715c3d2dd3508e3152f66704e7d73a693 100644
--- a/PhysicsAnalysis/AnalysisCommon/UserAnalysis/share/AnalysisSkeleton_topOptions_NEW.py
+++ b/PhysicsAnalysis/AnalysisCommon/UserAnalysis/share/AnalysisSkeleton_topOptions_NEW.py
@@ -215,7 +215,7 @@ AANTupleStream.OutputLevel = WARNING
 ###################### For interactive analysis
 #include ("PyAnalysisCore/InitPyAnalysisCore.py")
 
-from GaudiSvc.GaudiSvcConf import AuditorSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 ServiceMgr.AuditorSvc.Auditors  += [ "ChronoAuditor"]
 
 AthenaPoolCnvSvc = Service("AthenaPoolCnvSvc")
diff --git a/TileCalorimeter/TileCalib/TileCalibAlgs/share/jobOptions_NoiseCalib.py b/TileCalorimeter/TileCalib/TileCalibAlgs/share/jobOptions_NoiseCalib.py
index 1d5ef2d98437e4482a67131d61dbe337e792ef41..1a3ac4b7ced6587b619e5b96a6c6fe67de8ab7de 100755
--- a/TileCalorimeter/TileCalib/TileCalibAlgs/share/jobOptions_NoiseCalib.py
+++ b/TileCalorimeter/TileCalib/TileCalibAlgs/share/jobOptions_NoiseCalib.py
@@ -383,7 +383,7 @@ topSequence += theTileRawChNoiseCalibAlg
 if 'doPerfMon' in dir():
     if doPerfMon:
 
-        from GaudiSvc.GaudiSvcConf import AuditorSvc
+        from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
         theAuditorSvc = svcMgr.AuditorSvc
         theApp.AuditAlgorithms=True  
         theApp.AuditServices=True
diff --git a/TileCalorimeter/TileMonitoring/share/TileRec_topOptions.py b/TileCalorimeter/TileMonitoring/share/TileRec_topOptions.py
index 34c8d61108a19a5eb21f604ba85306fdb56e249b..72156ccc9624011c762c74829012fb3f87e5321b 100644
--- a/TileCalorimeter/TileMonitoring/share/TileRec_topOptions.py
+++ b/TileCalorimeter/TileMonitoring/share/TileRec_topOptions.py
@@ -389,7 +389,7 @@ if doAtlantis:
 #-----------------------
 if doPerfMon and not athenaCommonFlags.isOnline():
 
-    from GaudiSvc.GaudiSvcConf import AuditorSvc
+    from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
     theAuditorSvc = svcMgr.AuditorSvc
     theApp.AuditAlgorithms = True  
     theApp.AuditServices = True
diff --git a/TileCalorimeter/TileTBRec/share/jobOptions_TileOldTB.py b/TileCalorimeter/TileTBRec/share/jobOptions_TileOldTB.py
index 8bd47312ed0b60e160bf442772be7c2f8a9d301c..0b4625cb9132238b709dbe7b39bd6224e44ea8d3 100644
--- a/TileCalorimeter/TileTBRec/share/jobOptions_TileOldTB.py
+++ b/TileCalorimeter/TileTBRec/share/jobOptions_TileOldTB.py
@@ -40,14 +40,14 @@ if not 'OutputLevel' in dir():
     OutputLevel = 3
 
 if not hasattr(svcMgr, 'MessageSvc'):
-    from GaudiSvc.GaudiSvcConf import MessageSvc
+    from GaudiCoreSvc.GaudiCoreSvcConf import MessageSvc
     svcMgr += MessageSvc()
 svcMgr.MessageSvc.defaultLimit = 1000000
 svcMgr.MessageSvc.Format = "% F%50W%S%7W%R%T %0W%M"
 svcMgr.MessageSvc.OutputLevel  = OutputLevel
 
 if not hasattr(svcMgr, 'HistorySvc'):
-    from GaudiSvc.GaudiSvcConf import HistorySvc
+    from GaudiMonitor.GaudiMonitorConf import HistorySvc
     svcMgr += HistorySvc()
 svcMgr.HistorySvc.OutputLevel = 4
 
diff --git a/Trigger/TrigAnalysis/TrigInDetAnalysis/run/TrigInDetAnalysis_topOptions.py b/Trigger/TrigAnalysis/TrigInDetAnalysis/run/TrigInDetAnalysis_topOptions.py
index ad23d07132d2fb1ea2c274d15bb30714d0621c6e..007311f0d4156d17eebe40793d7bc049a37f3565 100644
--- a/Trigger/TrigAnalysis/TrigInDetAnalysis/run/TrigInDetAnalysis_topOptions.py
+++ b/Trigger/TrigAnalysis/TrigInDetAnalysis/run/TrigInDetAnalysis_topOptions.py
@@ -47,7 +47,7 @@ ServiceMgr.MessageSvc.OutputLevel = DEBUG
 
 theApp.EvtMax = -1
 
-from GaudiSvc.GaudiSvcConf import AuditorSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 ServiceMgr.AuditorSvc.Auditors  += [ "ChronoAuditor"]
 
 AthenaPoolCnvSvc = Service("AthenaPoolCnvSvc")
diff --git a/Trigger/TrigAnalysis/TrigInDetAnalysisExample/run/TrigInDetAnalysis_topOptions.py b/Trigger/TrigAnalysis/TrigInDetAnalysisExample/run/TrigInDetAnalysis_topOptions.py
index b511cbf9602cc39924df1503cc3d5b577fc99d6e..73a0706d0ed651b0e1585cf9820cbc5eeedd1e8a 100644
--- a/Trigger/TrigAnalysis/TrigInDetAnalysisExample/run/TrigInDetAnalysis_topOptions.py
+++ b/Trigger/TrigAnalysis/TrigInDetAnalysisExample/run/TrigInDetAnalysis_topOptions.py
@@ -116,7 +116,7 @@ ServiceMgr.MessageSvc.OutputLevel = DEBUG
 
 theApp.EvtMax = -1
 
-from GaudiSvc.GaudiSvcConf import AuditorSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 ServiceMgr.AuditorSvc.Auditors  += [ "ChronoAuditor"]
 
 AthenaPoolCnvSvc = Service("AthenaPoolCnvSvc")
diff --git a/Trigger/TrigAnalysis/TrigInDetAnalysisExample/run/process_run_0152116.py b/Trigger/TrigAnalysis/TrigInDetAnalysisExample/run/process_run_0152116.py
index 9d5821199ef20f45341e0843e0a05bc050c71987..6d1e1483b3691c9a8ade995c63cdbc4938e4e6c4 100644
--- a/Trigger/TrigAnalysis/TrigInDetAnalysisExample/run/process_run_0152116.py
+++ b/Trigger/TrigAnalysis/TrigInDetAnalysisExample/run/process_run_0152116.py
@@ -109,7 +109,7 @@ AANTupleStream.OutputLevel = FATAL
 
 theApp.EvtMax = -1
 
-from GaudiSvc.GaudiSvcConf import AuditorSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 ServiceMgr.AuditorSvc.Auditors  += [ "ChronoAuditor"]
 
 AthenaPoolCnvSvc = Service("AthenaPoolCnvSvc")
diff --git a/Trigger/TrigAnalysis/TrigInDetAnalysisExample/run/process_run_0152166.py b/Trigger/TrigAnalysis/TrigInDetAnalysisExample/run/process_run_0152166.py
index defb0eb2daf6fb2b61ba6158e31b7996483d7562..b30ac418102515983713b3c359f7b3032491212d 100644
--- a/Trigger/TrigAnalysis/TrigInDetAnalysisExample/run/process_run_0152166.py
+++ b/Trigger/TrigAnalysis/TrigInDetAnalysisExample/run/process_run_0152166.py
@@ -116,7 +116,7 @@ ServiceMgr.MessageSvc.OutputLevel = DEBUG
 
 theApp.EvtMax = -1
 
-from GaudiSvc.GaudiSvcConf import AuditorSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 ServiceMgr.AuditorSvc.Auditors  += [ "ChronoAuditor"]
 
 AthenaPoolCnvSvc = Service("AthenaPoolCnvSvc")
diff --git a/Trigger/TrigMonitoring/TrigCostMonitorMT/share/TrigCostMonitorMT_jobOptions.py b/Trigger/TrigMonitoring/TrigCostMonitorMT/share/TrigCostMonitorMT_jobOptions.py
index d50981472fac1beef617b1e954338d961246d5c5..ceb039dc92152597fc56f500cb39bec74c8723fd 100644
--- a/Trigger/TrigMonitoring/TrigCostMonitorMT/share/TrigCostMonitorMT_jobOptions.py
+++ b/Trigger/TrigMonitoring/TrigCostMonitorMT/share/TrigCostMonitorMT_jobOptions.py
@@ -9,7 +9,7 @@ Prefer the use of TrigCostMonitorMT.TrigCostMonitorMTConfig, if possible
 
 from AthenaCommon.AppMgr import ServiceMgr
 from AthenaCommon.AppMgr import theApp
-from GaudiSvc.GaudiSvcConf import AuditorSvc
+from GaudiCommonSvc.GaudiCommonSvcConf import AuditorSvc
 from TrigCostMonitorMT.TrigCostMonitorMTConf import TrigCostMTAuditor, TrigCostMTSvc
 from AthenaConfiguration.AllConfigFlags import ConfigFlags
diff --git a/Control/AthenaCommon/python/AtlasUnixStandardJob.py b/Control/AthenaCommon/python/AtlasUnixStandardJob.py
index 72d0573d59306d0ddc3a3d5219153b22b83b06d1..b9c97aa9306bae509154eede581bdc728b93482f 100755
--- a/Control/AthenaCommon/python/AtlasUnixStandardJob.py
+++ b/Control/AthenaCommon/python/AtlasUnixStandardJob.py
@@ -12,20 +12,22 @@ def _setupAtlasUnixStandardJob():
     from .AppMgr import ServiceMgr as svcMgr
 
     ## basic Gaudi services
+    # ToolSvc is already added in AppMgr.py.
     import GaudiSvc.GaudiSvcConf as GaudiSvcConf
-    svcMgr += GaudiSvcConf.IncidentSvc()
-    svcMgr += GaudiSvcConf.EvtPersistencySvc( "EventPersistencySvc" )
-    svcMgr += GaudiSvcConf.HistogramSvc( "HistogramDataSvc" )
+    import GaudiCoreSvc.GaudiCoreSvcConf as GaudiCoreSvcConf
+    import GaudiCommonSvc.GaudiCommonSvcConf as GaudiCommonSvcConf
+    svcMgr += GaudiCoreSvcConf.IncidentSvc()
+    svcMgr += GaudiCommonSvcConf.EvtPersistencySvc( "EventPersistencySvc" )
+    svcMgr += GaudiCommonSvcConf.HistogramSvc( "HistogramDataSvc" )
     svcMgr += GaudiSvcConf.NTupleSvc()
-    # ToolSvc is already added in AppMgr.py.
     svcMgr += GaudiSvcConf.RndmGenSvc()
-    svcMgr += GaudiSvcConf.ChronoStatSvc()
+    svcMgr += GaudiCommonSvcConf.ChronoStatSvc()
 
     import GaudiAud.GaudiAudConf as GaudiAudConf
     svcMgr.AuditorSvc += GaudiAudConf.AlgContextAuditor()
 
     # make the message service available
     # from GaudiSvc.GaudiSvcConf import MessageSvc
     svcMgr.MessageSvc = theApp.service( "MessageSvc" )     # already instantiated
 
     # StoreGate services configuration
@@ -12,20 +12,22 @@ def _setupAtlasUnixStandardJob():
 
     # make the message service available
-    # from GaudiSvc.GaudiSvcConf import MessageSvc
+    # from GaudiCoreSvc.GaudiCoreSvcConf import MessageSvc
     svcMgr.MessageSvc = theApp.service( "MessageSvc" )     # already instantiated
 